@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-FAD; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/cl-fad/fad.lisp,v 1.26 2006/04/21 21:33:29 edi Exp $
+;;; $Header: /usr/local/cvsrep/cl-fad/fad.lisp,v 1.28 2006/08/11 14:07:29 edi Exp $
 
 ;;; Copyright (c) 2004, Peter Seibel.  All rights reserved.
 ;;; Copyright (c) 2004-2006, Dr. Edmund Weitz.  All rights reserved.
@@ -204,12 +204,14 @@ signaled if the directory DIRNAME does not exist."
 #-:sbcl
 (defvar *stream-buffer-size* 8192)
 #-:sbcl
-(defun copy-stream (from to)
+(defun copy-stream (from to &optional (checkp t))
   "Copies into TO \(a stream) from FROM \(also a stream) until the end
 of FROM is reached, in blocks of *stream-buffer-size*.  The streams
-should have the same element type."
-  (unless (subtypep (stream-element-type to) (stream-element-type from))
-    (error "Incompatible streams ~A and ~A." from to))
+should have the same element type.  If CHECKP is true, the streams are
+checked for compatibility of their types."
+  (when checkp
+    (unless (subtypep (stream-element-type to) (stream-element-type from))
+      (error "Incompatible streams ~A and ~A." from to)))
   (let ((buf (make-array *stream-buffer-size*
                          :element-type (stream-element-type from))))
     (loop
@@ -285,6 +287,7 @@ DIRNAME does not exist."
 ;; stuff for Nikodemus Siivola's HYPERDOC
 ;; see <http://common-lisp.net/project/hyperdoc/>
 ;; and <http://www.cliki.net/hyperdoc>
+;; also used by LW-ADD-ONS
 
 #-:abcl
 (defvar *hyperdoc-base-uri* "http://weitz.de/cl-fad/")
